@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-combinators
-version: 1.0.3.1
-id: conduit-combinators-1.0.3.1-06dc60511fa029ec23603920d7a2f7c9
-key: condu_J9aCI8Dr9Mo0smoWLcap7l
+version: 1.0.3
+id: conduit-combinators-1.0.3-9d89593f1e4b80567f813970d1f8b1d4
+key: condu_KBUvr6mW8gjB4VbMZ40kf1
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/conduit-combinators
@@ -18,31 +18,31 @@ exposed-modules:
     Data.Conduit.Combinators.Stream
 hidden-modules: Data.Conduit.Combinators.Unqualified
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
-hs-libraries: HSconduit-combinators-1.0.3.1-J9aCI8Dr9Mo0smoWLcap7l
+import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3
+hs-libraries: HSconduit-combinators-1.0.3-KBUvr6mW8gjB4VbMZ40kf1
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    chunked-data-0.2.0-a32ff507f486d0cf08dd0f1ae2d814dc
-    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
-    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
+    chunked-data-0.2.0-ed90e8d1292404e980f8a818efffd356
+    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
+    conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    mono-traversable-0.10.2-183dbee45ad80b580fee3545c451925a
-    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    mono-traversable-0.10.1-4a434efe4dfeb2b3479b76c4f64320d6
+    mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
-    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
     unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    void-0.7.1-255c5771d2d826ed3cb8a752061ff594
+    void-0.7.1-662e5f28c19568c0aec0b2de7532ac34
 haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
 haddock-html: /usr/share/doc/haskell-conduit-combinators/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
